@@ -1,7 +1,7 @@
 from logging import getLogger
 from unittest import TestCase
 
-from .command import CommandRunner
+from .command.command_runner import CommandRunnerImpl
 from .list_remote_factory import ListRemoteFactoryImpl
 from .repository import GithubRepository
 from .tests import network
@@ -11,7 +11,7 @@ from .tests import network
 class RemoteListFactoryTests(TestCase):
     def setUp(self) -> None:
         self.factory = ListRemoteFactoryImpl(
-            command_runner=CommandRunner(getLogger(__name__))
+            command_runner=CommandRunnerImpl(getLogger(__name__))
         )
 
     def test_for_non_existing_repo_we_get_none(self) -> None:
